/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

/*
 * This file is auto-generated by Qpid Gentools v.0.1 - do not modify.
 * Supported AMQP versions:
 *   8-0
 */

#ifndef qpid_framing_AMQP_ClientOperations__
#define qpid_framing_AMQP_ClientOperations__

#include <sstream>

#include <FieldTable.h>
#include <ProtocolVersion.h>
#include <ProtocolVersionException.h>

namespace qpid {
namespace framing {

class AMQP_ClientProxy;

class AMQP_ClientOperations
{
protected:
    ProtocolVersion version;
	AMQP_ClientOperations() {}

public:
    AMQP_ClientOperations(u_int8_t major, u_int8_t minor) : version(major, minor) {}
    AMQP_ClientOperations(ProtocolVersion& version) : version(version) {}
    virtual ~AMQP_ClientOperations() {}

    inline u_int8_t getMajor() const { return version.getMajor(); }
    inline u_int8_t getMinor() const { return version.getMinor(); }
    inline const ProtocolVersion& getVersion() const { return version; }
    inline bool isVersion(u_int8_t _major, u_int8_t _minor) const
    {
        return version.equals(_major, _minor);
    }
    inline bool isVersion(ProtocolVersion& _version) const
    {
        return version.equals(_version);
    }

	// Include framing constant declarations
	#include <AMQP_Constants.h>
	
    // Inner classes

    // ==================== class AccessHandler ====================
    class AccessHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        AccessHandler() {}
    public:
        AccessHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~AccessHandler() {}

        // Protocol methods

        virtual void requestOk( u_int16_t channel,
                            u_int16_t ticket ) = 0;
    }; // class AccessHandler

    // ==================== class BasicHandler ====================
    class BasicHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        BasicHandler() {}
    public:
        BasicHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~BasicHandler() {}

        // Protocol methods

        virtual void cancelOk( u_int16_t channel,
                            const string& consumerTag ) = 0;

        virtual void consumeOk( u_int16_t channel,
                            const string& consumerTag ) = 0;

        virtual void deliver( u_int16_t channel,
                            const string& consumerTag,
                            u_int64_t deliveryTag,
                            bool redelivered,
                            const string& exchange,
                            const string& routingKey ) = 0;

        virtual void getEmpty( u_int16_t channel,
                            const string& clusterId ) = 0;

        virtual void getOk( u_int16_t channel,
                            u_int64_t deliveryTag,
                            bool redelivered,
                            const string& exchange,
                            const string& routingKey,
                            u_int32_t messageCount ) = 0;

        virtual void qosOk( u_int16_t channel ) = 0;

        virtual void recoverOk( u_int16_t channel ) = 0;

        virtual void return_( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            const string& exchange,
                            const string& routingKey ) = 0;
    }; // class BasicHandler

    // ==================== class ChannelHandler ====================
    class ChannelHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        ChannelHandler() {}
    public:
        ChannelHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~ChannelHandler() {}

        // Protocol methods

        virtual void alert( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            const FieldTable& details ) = 0;

        virtual void close( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            u_int16_t classId,
                            u_int16_t methodId ) = 0;

        virtual void closeOk( u_int16_t channel ) = 0;

        virtual void flow( u_int16_t channel,
                            bool active ) = 0;

        virtual void flowOk( u_int16_t channel,
                            bool active ) = 0;

        virtual void openOk( u_int16_t channel ) = 0;
    }; // class ChannelHandler

    // ==================== class ConnectionHandler ====================
    class ConnectionHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        ConnectionHandler() {}
    public:
        ConnectionHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~ConnectionHandler() {}

        // Protocol methods

        virtual void close( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            u_int16_t classId,
                            u_int16_t methodId ) = 0;

        virtual void closeOk( u_int16_t channel ) = 0;

        virtual void openOk( u_int16_t channel,
                            const string& knownHosts ) = 0;

        virtual void redirect( u_int16_t channel,
                            const string& host,
                            const string& knownHosts ) = 0;

        virtual void secure( u_int16_t channel,
                            const string& challenge ) = 0;

        virtual void start( u_int16_t channel,
                            u_int8_t versionMajor,
                            u_int8_t versionMinor,
                            const FieldTable& serverProperties,
                            const string& mechanisms,
                            const string& locales ) = 0;

        virtual void tune( u_int16_t channel,
                            u_int16_t channelMax,
                            u_int32_t frameMax,
                            u_int16_t heartbeat ) = 0;
    }; // class ConnectionHandler

    // ==================== class DtxHandler ====================
    class DtxHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        DtxHandler() {}
    public:
        DtxHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~DtxHandler() {}

        // Protocol methods

        virtual void selectOk( u_int16_t channel ) = 0;

        virtual void startOk( u_int16_t channel ) = 0;
    }; // class DtxHandler

    // ==================== class ExchangeHandler ====================
    class ExchangeHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        ExchangeHandler() {}
    public:
        ExchangeHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~ExchangeHandler() {}

        // Protocol methods

        virtual void declareOk( u_int16_t channel ) = 0;

        virtual void deleteOk( u_int16_t channel ) = 0;
    }; // class ExchangeHandler

    // ==================== class FileHandler ====================
    class FileHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        FileHandler() {}
    public:
        FileHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~FileHandler() {}

        // Protocol methods

        virtual void cancelOk( u_int16_t channel,
                            const string& consumerTag ) = 0;

        virtual void consumeOk( u_int16_t channel,
                            const string& consumerTag ) = 0;

        virtual void deliver( u_int16_t channel,
                            const string& consumerTag,
                            u_int64_t deliveryTag,
                            bool redelivered,
                            const string& exchange,
                            const string& routingKey,
                            const string& identifier ) = 0;

        virtual void open( u_int16_t channel,
                            const string& identifier,
                            u_int64_t contentSize ) = 0;

        virtual void openOk( u_int16_t channel,
                            u_int64_t stagedSize ) = 0;

        virtual void qosOk( u_int16_t channel ) = 0;

        virtual void return_( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            const string& exchange,
                            const string& routingKey ) = 0;

        virtual void stage( u_int16_t channel ) = 0;
    }; // class FileHandler

    // ==================== class QueueHandler ====================
    class QueueHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        QueueHandler() {}
    public:
        QueueHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~QueueHandler() {}

        // Protocol methods

        virtual void bindOk( u_int16_t channel ) = 0;

        virtual void declareOk( u_int16_t channel,
                            const string& queue,
                            u_int32_t messageCount,
                            u_int32_t consumerCount ) = 0;

        virtual void deleteOk( u_int16_t channel,
                            u_int32_t messageCount ) = 0;

        virtual void purgeOk( u_int16_t channel,
                            u_int32_t messageCount ) = 0;
    }; // class QueueHandler

    // ==================== class StreamHandler ====================
    class StreamHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        StreamHandler() {}
    public:
        StreamHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~StreamHandler() {}

        // Protocol methods

        virtual void cancelOk( u_int16_t channel,
                            const string& consumerTag ) = 0;

        virtual void consumeOk( u_int16_t channel,
                            const string& consumerTag ) = 0;

        virtual void deliver( u_int16_t channel,
                            const string& consumerTag,
                            u_int64_t deliveryTag,
                            const string& exchange,
                            const string& queue ) = 0;

        virtual void qosOk( u_int16_t channel ) = 0;

        virtual void return_( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            const string& exchange,
                            const string& routingKey ) = 0;
    }; // class StreamHandler

    // ==================== class TestHandler ====================
    class TestHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        TestHandler() {}
    public:
        TestHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~TestHandler() {}

        // Protocol methods

        virtual void content( u_int16_t channel ) = 0;

        virtual void contentOk( u_int16_t channel,
                            u_int32_t contentChecksum ) = 0;

        virtual void integer( u_int16_t channel,
                            u_int8_t integer1,
                            u_int16_t integer2,
                            u_int32_t integer3,
                            u_int64_t integer4,
                            u_int8_t operation ) = 0;

        virtual void integerOk( u_int16_t channel,
                            u_int64_t result ) = 0;

        virtual void string_( u_int16_t channel,
                            const string& string1,
                            const string& string2,
                            u_int8_t operation ) = 0;

        virtual void stringOk( u_int16_t channel,
                            const string& result ) = 0;

        virtual void table( u_int16_t channel,
                            const FieldTable& table,
                            u_int8_t integerOp,
                            u_int8_t stringOp ) = 0;

        virtual void tableOk( u_int16_t channel,
                            u_int64_t integerResult,
                            const string& stringResult ) = 0;
    }; // class TestHandler

    // ==================== class TunnelHandler ====================
    class TunnelHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        TunnelHandler() {}
    public:
        TunnelHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~TunnelHandler() {}

        // Protocol methods

    }; // class TunnelHandler

    // ==================== class TxHandler ====================
    class TxHandler
    {
    private:
        AMQP_ClientProxy* parent;

        // Constructors and destructors

    protected:
        TxHandler() {}
    public:
        TxHandler(AMQP_ClientProxy* _parent) {parent = _parent;}
        virtual ~TxHandler() {}

        // Protocol methods

        virtual void commitOk( u_int16_t channel ) = 0;

        virtual void rollbackOk( u_int16_t channel ) = 0;

        virtual void selectOk( u_int16_t channel ) = 0;
    }; // class TxHandler
	
    // Method handler get methods

    virtual AMQP_ClientOperations::AccessHandler* getAccessHandler() = 0;
    virtual AMQP_ClientOperations::BasicHandler* getBasicHandler() = 0;
    virtual AMQP_ClientOperations::ChannelHandler* getChannelHandler() = 0;
    virtual AMQP_ClientOperations::ConnectionHandler* getConnectionHandler() = 0;
    virtual AMQP_ClientOperations::DtxHandler* getDtxHandler() = 0;
    virtual AMQP_ClientOperations::ExchangeHandler* getExchangeHandler() = 0;
    virtual AMQP_ClientOperations::FileHandler* getFileHandler() = 0;
    virtual AMQP_ClientOperations::QueueHandler* getQueueHandler() = 0;
    virtual AMQP_ClientOperations::StreamHandler* getStreamHandler() = 0;
    virtual AMQP_ClientOperations::TestHandler* getTestHandler() = 0;
    virtual AMQP_ClientOperations::TxHandler* getTxHandler() = 0;

}; /* class AMQP_ClientOperations */

} /* namespace framing */
} /* namespace qpid */

#endif
