/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

/*
 * This file is auto-generated by Qpid Gentools v.0.1 - do not modify.
 * Supported AMQP versions:
 *   8-0
 */
 
#ifndef qpid_framing_AMQP_ServerOperations__
#define qpid_framing_AMQP_ServerOperations__

#include <sstream>

#include <FieldTable.h>
#include <ProtocolVersion.h>
#include <ProtocolVersionException.h>

namespace qpid {
namespace framing {

class AMQP_ServerProxy;
class AMQP_ClientProxy;

class AMQP_ServerOperations
{
protected:
    ProtocolVersion version;
	AMQP_ServerOperations() {}

public:
    AMQP_ServerOperations(u_int8_t major, u_int8_t minor) : version(major, minor) {}
    AMQP_ServerOperations(ProtocolVersion& version) : version(version) {}
    virtual ~AMQP_ServerOperations() {}

    inline u_int8_t getMajor() const { return version.getMajor(); }
    inline u_int8_t getMinor() const { return version.getMinor(); }
    inline const ProtocolVersion& getVersion() const { return version; }
    inline bool isVersion(u_int8_t _major, u_int8_t _minor) const
    {
        return version.equals(_major, _minor);
    }
    inline bool isVersion(ProtocolVersion& _version) const
    {
        return version.equals(_version);
    }
    
	// Include framing constant declarations
	#include <AMQP_Constants.h>

    // Inner classes

    // ==================== class AccessHandler ====================
    class AccessHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        AccessHandler() {}
    public:
        AccessHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~AccessHandler() {}

        // Protocol methods

        virtual void request( u_int16_t channel,
                            const string& realm,
                            bool exclusive,
                            bool passive,
                            bool active,
                            bool write,
                            bool read ) = 0;
    }; // class AccessHandler

    // ==================== class BasicHandler ====================
    class BasicHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        BasicHandler() {}
    public:
        BasicHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~BasicHandler() {}

        // Protocol methods

        virtual void ack( u_int16_t channel,
                            u_int64_t deliveryTag,
                            bool multiple ) = 0;

        virtual void cancel( u_int16_t channel,
                            const string& consumerTag,
                            bool nowait ) = 0;

        virtual void consume( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            const string& consumerTag,
                            bool noLocal,
                            bool noAck,
                            bool exclusive,
                            bool nowait,
                            const FieldTable& arguments ) = 0;

        virtual void get( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            bool noAck ) = 0;

        virtual void publish( u_int16_t channel,
                            u_int16_t ticket,
                            const string& exchange,
                            const string& routingKey,
                            bool mandatory,
                            bool immediate ) = 0;

        virtual void qos( u_int16_t channel,
                            u_int32_t prefetchSize,
                            u_int16_t prefetchCount,
                            bool global ) = 0;

        virtual void recover( u_int16_t channel,
                            bool requeue ) = 0;

        virtual void reject( u_int16_t channel,
                            u_int64_t deliveryTag,
                            bool requeue ) = 0;
    }; // class BasicHandler

    // ==================== class ChannelHandler ====================
    class ChannelHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        ChannelHandler() {}
    public:
        ChannelHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~ChannelHandler() {}

        // Protocol methods

        virtual void close( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            u_int16_t classId,
                            u_int16_t methodId ) = 0;

        virtual void closeOk( u_int16_t channel ) = 0;

        virtual void flow( u_int16_t channel,
                            bool active ) = 0;

        virtual void flowOk( u_int16_t channel,
                            bool active ) = 0;

        virtual void open( u_int16_t channel,
                            const string& outOfBand ) = 0;
    }; // class ChannelHandler

    // ==================== class ConnectionHandler ====================
    class ConnectionHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        ConnectionHandler() {}
    public:
        ConnectionHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~ConnectionHandler() {}

        // Protocol methods

        virtual void close( u_int16_t channel,
                            u_int16_t replyCode,
                            const string& replyText,
                            u_int16_t classId,
                            u_int16_t methodId ) = 0;

        virtual void closeOk( u_int16_t channel ) = 0;

        virtual void open( u_int16_t channel,
                            const string& virtualHost,
                            const string& capabilities,
                            bool insist ) = 0;

        virtual void secureOk( u_int16_t channel,
                            const string& response ) = 0;

        virtual void startOk( u_int16_t channel,
                            const FieldTable& clientProperties,
                            const string& mechanism,
                            const string& response,
                            const string& locale ) = 0;

        virtual void tuneOk( u_int16_t channel,
                            u_int16_t channelMax,
                            u_int32_t frameMax,
                            u_int16_t heartbeat ) = 0;
    }; // class ConnectionHandler

    // ==================== class DtxHandler ====================
    class DtxHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        DtxHandler() {}
    public:
        DtxHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~DtxHandler() {}

        // Protocol methods

        virtual void select( u_int16_t channel ) = 0;

        virtual void start( u_int16_t channel,
                            const string& dtxIdentifier ) = 0;
    }; // class DtxHandler

    // ==================== class ExchangeHandler ====================
    class ExchangeHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        ExchangeHandler() {}
    public:
        ExchangeHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~ExchangeHandler() {}

        // Protocol methods

        virtual void declare( u_int16_t channel,
                            u_int16_t ticket,
                            const string& exchange,
                            const string& type,
                            bool passive,
                            bool durable,
                            bool autoDelete,
                            bool internal,
                            bool nowait,
                            const FieldTable& arguments ) = 0;

        virtual void delete_( u_int16_t channel,
                            u_int16_t ticket,
                            const string& exchange,
                            bool ifUnused,
                            bool nowait ) = 0;
    }; // class ExchangeHandler

    // ==================== class FileHandler ====================
    class FileHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        FileHandler() {}
    public:
        FileHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~FileHandler() {}

        // Protocol methods

        virtual void ack( u_int16_t channel,
                            u_int64_t deliveryTag,
                            bool multiple ) = 0;

        virtual void cancel( u_int16_t channel,
                            const string& consumerTag,
                            bool nowait ) = 0;

        virtual void consume( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            const string& consumerTag,
                            bool noLocal,
                            bool noAck,
                            bool exclusive,
                            bool nowait ) = 0;

        virtual void open( u_int16_t channel,
                            const string& identifier,
                            u_int64_t contentSize ) = 0;

        virtual void openOk( u_int16_t channel,
                            u_int64_t stagedSize ) = 0;

        virtual void publish( u_int16_t channel,
                            u_int16_t ticket,
                            const string& exchange,
                            const string& routingKey,
                            bool mandatory,
                            bool immediate,
                            const string& identifier ) = 0;

        virtual void qos( u_int16_t channel,
                            u_int32_t prefetchSize,
                            u_int16_t prefetchCount,
                            bool global ) = 0;

        virtual void reject( u_int16_t channel,
                            u_int64_t deliveryTag,
                            bool requeue ) = 0;

        virtual void stage( u_int16_t channel ) = 0;
    }; // class FileHandler

    // ==================== class QueueHandler ====================
    class QueueHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        QueueHandler() {}
    public:
        QueueHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~QueueHandler() {}

        // Protocol methods

        virtual void bind( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            const string& exchange,
                            const string& routingKey,
                            bool nowait,
                            const FieldTable& arguments ) = 0;

        virtual void declare( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            bool passive,
                            bool durable,
                            bool exclusive,
                            bool autoDelete,
                            bool nowait,
                            const FieldTable& arguments ) = 0;

        virtual void delete_( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            bool ifUnused,
                            bool ifEmpty,
                            bool nowait ) = 0;

        virtual void purge( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            bool nowait ) = 0;
    }; // class QueueHandler

    // ==================== class StreamHandler ====================
    class StreamHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        StreamHandler() {}
    public:
        StreamHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~StreamHandler() {}

        // Protocol methods

        virtual void cancel( u_int16_t channel,
                            const string& consumerTag,
                            bool nowait ) = 0;

        virtual void consume( u_int16_t channel,
                            u_int16_t ticket,
                            const string& queue,
                            const string& consumerTag,
                            bool noLocal,
                            bool exclusive,
                            bool nowait ) = 0;

        virtual void publish( u_int16_t channel,
                            u_int16_t ticket,
                            const string& exchange,
                            const string& routingKey,
                            bool mandatory,
                            bool immediate ) = 0;

        virtual void qos( u_int16_t channel,
                            u_int32_t prefetchSize,
                            u_int16_t prefetchCount,
                            u_int32_t consumeRate,
                            bool global ) = 0;
    }; // class StreamHandler

    // ==================== class TestHandler ====================
    class TestHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        TestHandler() {}
    public:
        TestHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~TestHandler() {}

        // Protocol methods

        virtual void content( u_int16_t channel ) = 0;

        virtual void contentOk( u_int16_t channel,
                            u_int32_t contentChecksum ) = 0;

        virtual void integer( u_int16_t channel,
                            u_int8_t integer1,
                            u_int16_t integer2,
                            u_int32_t integer3,
                            u_int64_t integer4,
                            u_int8_t operation ) = 0;

        virtual void integerOk( u_int16_t channel,
                            u_int64_t result ) = 0;

        virtual void string_( u_int16_t channel,
                            const string& string1,
                            const string& string2,
                            u_int8_t operation ) = 0;

        virtual void stringOk( u_int16_t channel,
                            const string& result ) = 0;

        virtual void table( u_int16_t channel,
                            const FieldTable& table,
                            u_int8_t integerOp,
                            u_int8_t stringOp ) = 0;

        virtual void tableOk( u_int16_t channel,
                            u_int64_t integerResult,
                            const string& stringResult ) = 0;
    }; // class TestHandler

    // ==================== class TunnelHandler ====================
    class TunnelHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        TunnelHandler() {}
    public:
        TunnelHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~TunnelHandler() {}

        // Protocol methods

        virtual void request( u_int16_t channel,
                            const FieldTable& metaData ) = 0;
    }; // class TunnelHandler

    // ==================== class TxHandler ====================
    class TxHandler
    {
    private:
        AMQP_ServerProxy* parent;

        // Constructors and destructors

    protected:
        TxHandler() {}
    public:
        TxHandler(AMQP_ServerProxy* _parent) {parent = _parent;}
        virtual ~TxHandler() {}

        // Protocol methods

        virtual void commit( u_int16_t channel ) = 0;

        virtual void rollback( u_int16_t channel ) = 0;

        virtual void select( u_int16_t channel ) = 0;
    }; // class TxHandler

    // Method handler get methods

    virtual AMQP_ServerOperations::AccessHandler* getAccessHandler() = 0;
    virtual AMQP_ServerOperations::BasicHandler* getBasicHandler() = 0;
    virtual AMQP_ServerOperations::ChannelHandler* getChannelHandler() = 0;
    virtual AMQP_ServerOperations::ConnectionHandler* getConnectionHandler() = 0;
    virtual AMQP_ServerOperations::DtxHandler* getDtxHandler() = 0;
    virtual AMQP_ServerOperations::ExchangeHandler* getExchangeHandler() = 0;
    virtual AMQP_ServerOperations::FileHandler* getFileHandler() = 0;
    virtual AMQP_ServerOperations::QueueHandler* getQueueHandler() = 0;
    virtual AMQP_ServerOperations::StreamHandler* getStreamHandler() = 0;
    virtual AMQP_ServerOperations::TestHandler* getTestHandler() = 0;
    virtual AMQP_ServerOperations::TunnelHandler* getTunnelHandler() = 0;
    virtual AMQP_ServerOperations::TxHandler* getTxHandler() = 0;

}; /* class AMQP_ServerOperations */

} /* namespace framing */
} /* namespace qpid */

#endif
